@@ -1,7 +1,7 @@
 import io
 import json
 from collections import defaultdict
-from functools import cache
+from functools import lru_cache
 from itertools import chain
 
 from django.apps import apps
@@ -51,7 +51,7 @@ def _validate_spec(spec):
 
 def specs_for_models(models, spec=None):
     spec = {} if spec is None else spec
-    return (_validate_spec(spec | {"model": cls._meta.label_lower}) for cls in models)
+    return (_validate_spec({**spec, "model": cls._meta.label_lower}) for cls in models)
 
 
 def specs_for_derived_models(cls, spec=None):
@@ -144,7 +144,7 @@ def load_dump(data, *, progress=silence, ignorenonexistent=False):
 
 
 def pk_cache():
-    @cache
+    @lru_cache(maxsize=None)
     def pks(model):
         return set(model._default_manager.values_list("pk", flat=True))
 
